Method: JSOS#each

Defined in:
lib/jsos.rb

#each(&block) ⇒ Hash|Enumerator

Yield to block for each method on the object, passing method name and value as parameters to the block.

Returns:

  • (Hash|Enumerator)

See Also:

  • JSOS.[Enumerator[Enumerator#each]


80
81
82
# File 'lib/jsos.rb', line 80

def each &block
  self.to_h.each{ |k, v| yield k, v }
end